==> qtjambi-charts-debuginfo-windows-x64-6.5.3.jar: sources/QtJambiCharts/QBoxSet_shell.h <==
#ifndef QBOXSET_SHELL_H
#define QBOXSET_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtCharts/qboxset.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qbrush.h>
#include <QtGui/qpen.h>
#include <QtJambi/RegistryAPI>


class QBoxSet_shell : public QBoxSet, public QtJambiShellInterface
{
public:
    QBoxSet_shell(const QString label0 = QString(), QObject* parent1 = nullptr);
    QBoxSet_shell(const qreal le0, const qreal lq1, const qreal m2, const qreal uq3, const qreal ue4, const QString label5 = QString(), QObject* parent6 = nullptr);
    ~QBoxSet_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QBoxSet_access : public QBoxSet
{
};

#endif // QBOXSET_SHELL_H

==> qtjambi-charts-debuginfo-windows-x64-6.5.8.jar: sources/QtJambiCharts/QBoxSet_shell.h <==
#ifndef QBOXSET_SHELL_H
#define QBOXSET_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtCharts/qboxset.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qbrush.h>
#include <QtGui/qpen.h>
#include <QtJambi/RegistryAPI>


class QBoxSet_shell : public QBoxSet, public QtJambiShellInterface
{
public:
    QBoxSet_shell(const QString label0 = QString(), QObject* parent1 = nullptr);
    QBoxSet_shell(const qreal le0, const qreal lq1, const qreal m2, const qreal uq3, const qreal ue4, const QString label5 = QString(), QObject* parent6 = nullptr);
    ~QBoxSet_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QBoxSet_mshell;
    friend class QBoxSet_oshell;
};


class QBoxSet_mshell : public QBoxSet_shell
{
public:
    using QBoxSet_shell::QBoxSet_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QBoxSet_oshell : public QBoxSet_mshell
{
public:
    using QBoxSet_mshell::QBoxSet_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QBoxSet_access : public QBoxSet
{
};

#endif // QBOXSET_SHELL_H
